@@ -262,9 +262,9 @@ class Test:
             (p.plural_adj, "cat's", "cats'"),
             (p.plural_adj, "child's", "children's"),
         ):
-            assert (
-                fn(sing) == plur
-            ), f'{fn.__name__}("{sing}") == "{fn(sing)}" != "{plur}"'
+            assert fn(sing) == plur, (
+                f'{fn.__name__}("{sing}") == "{fn(sing)}" != "{plur}"'
+            )
 
         for sing, num, plur in (
             ("cow", 1, "cow"),
@@ -341,9 +341,9 @@ class Test:
             ("to her", "to them"),
             ("to herself", "to themselves"),
         ):
-            assert (
-                p.singular_noun(plur) == sing
-            ), f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            assert p.singular_noun(plur) == sing, (
+                f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            )
             assert p.inflect("singular_noun('%s')" % plur) == sing
 
         p.gender("masculine")
@@ -354,9 +354,9 @@ class Test:
             ("to him", "to them"),
             ("to himself", "to themselves"),
         ):
-            assert (
-                p.singular_noun(plur) == sing
-            ), f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            assert p.singular_noun(plur) == sing, (
+                f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            )
             assert p.inflect("singular_noun('%s')" % plur) == sing
 
         p.gender("gender-neutral")
@@ -367,9 +367,9 @@ class Test:
             ("to them", "to them"),
             ("to themself", "to themselves"),
         ):
-            assert (
-                p.singular_noun(plur) == sing
-            ), f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            assert p.singular_noun(plur) == sing, (
+                f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            )
             assert p.inflect("singular_noun('%s')" % plur) == sing
 
         p.gender("neuter")
@@ -380,9 +380,9 @@ class Test:
             ("to it", "to them"),
             ("to itself", "to themselves"),
         ):
-            assert (
-                p.singular_noun(plur) == sing
-            ), f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            assert p.singular_noun(plur) == sing, (
+                f"singular_noun({plur}) == {p.singular_noun(plur)} != {sing}"
+            )
             assert p.inflect("singular_noun('%s')" % plur) == sing
 
         with pytest.raises(BadGenderError):
@@ -612,9 +612,9 @@ class Test:
             ("zoo", "zoos"),
             ("tomato", "tomatoes"),
         ):
-            assert (
-                p._plnoun(sing) == plur
-            ), f'p._plnoun("{sing}") == {p._plnoun(sing)} != "{plur}"'
+            assert p._plnoun(sing) == plur, (
+                f'p._plnoun("{sing}") == {p._plnoun(sing)} != "{plur}"'
+            )
 
             assert p._sinoun(plur) == sing, f'p._sinoun("{plur}") != "{sing}"'
 
@@ -743,6 +743,7 @@ class Test:
             ("tuna's", "tuna's"),
             ("TUNA's", "TUNA's"),
             ("bad", False),
+            ("'", False),
             pytest.param(
                 "JOHN's",
                 "JOHNS'",
